@@ -16,6 +16,7 @@ import (
 	"net/url"
 	"os"
 	"os/exec"
+	"os/signal"
 	"os/user"
 	"path"
 	"path/filepath"
@@ -29,8 +30,10 @@ import (
 	"kitty/tools/tty"
 	"kitty/tools/tui"
 	"kitty/tools/tui/loop"
+	"kitty/tools/tui/shell_integration"
 	"kitty/tools/utils"
 	"kitty/tools/utils/secrets"
+	"kitty/tools/utils/shlex"
 	"kitty/tools/utils/shm"
 
 	"golang.org/x/exp/maps"
@@ -297,14 +300,14 @@ func make_tarfile(cd *connection_data, get_local_env func(string) (string, bool)
 		}
 		return nil
 	}
-	add_entries := func(prefix string, items ...Entry) error {
+	add_entries := func(prefix string, items ...shell_integration.Entry) error {
 		for _, item := range items {
 			err := add(
 				&tar.Header{
-					Typeflag: item.metadata.Typeflag, Name: path.Join(prefix, path.Base(item.metadata.Name)), Format: tar.FormatPAX,
-					Size: int64(len(item.data)), Mode: item.metadata.Mode, ModTime: item.metadata.ModTime,
-					AccessTime: item.metadata.AccessTime, ChangeTime: item.metadata.ChangeTime,
-				}, item.data)
+					Typeflag: item.Metadata.Typeflag, Name: path.Join(prefix, path.Base(item.Metadata.Name)), Format: tar.FormatPAX,
+					Size: int64(len(item.Data)), Mode: item.Metadata.Mode, ModTime: item.Metadata.ModTime,
+					AccessTime: item.Metadata.AccessTime, ChangeTime: item.Metadata.ChangeTime,
+				}, item.Data)
 			if err != nil {
 				return err
 			}
@@ -314,16 +317,16 @@ func make_tarfile(cd *connection_data, get_local_env func(string) (string, bool)
 	}
 	add_data(fe{"data.sh", utils.UnsafeStringToBytes(env_script)})
 	if cd.script_type == "sh" {
-		add_data(fe{"bootstrap-utils.sh", Data()[path.Join("shell-integration/ssh/bootstrap-utils.sh")].data})
+		add_data(fe{"bootstrap-utils.sh", shell_integration.Data()[path.Join("shell-integration/ssh/bootstrap-utils.sh")].Data})
 	}
 	if ksi != "" {
-		for _, fname := range Data().files_matching(
+		for _, fname := range shell_integration.Data().FilesMatching(
 			"shell-integration/",
 			"shell-integration/ssh/.+",        // bootstrap files are sent as command line args
 			"shell-integration/zsh/kitty.zsh", // backward compat file not needed by ssh kitten
 		) {
 			arcname := path.Join("home/", rd, "/", path.Dir(fname))
-			err = add_entries(arcname, Data()[fname])
+			err = add_entries(arcname, shell_integration.Data()[fname])
 			if err != nil {
 				return nil, err
 			}
@@ -336,15 +339,15 @@ func make_tarfile(cd *connection_data, get_local_env func(string) (string, bool)
 			return nil, err
 		}
 		for _, x := range []string{"kitty", "kitten"} {
-			err = add_entries(path.Join(arcname, "bin"), Data()[path.Join("shell-integration", "ssh", x)])
+			err = add_entries(path.Join(arcname, "bin"), shell_integration.Data()[path.Join("shell-integration", "ssh", x)])
 			if err != nil {
 				return nil, err
 			}
 		}
 	}
-	err = add_entries(path.Join("home", ".terminfo"), Data()["terminfo/kitty.terminfo"])
+	err = add_entries(path.Join("home", ".terminfo"), shell_integration.Data()["terminfo/kitty.terminfo"])
 	if err == nil {
-		err = add_entries(path.Join("home", ".terminfo", "x"), Data()["terminfo/x/xterm-kitty"])
+		err = add_entries(path.Join("home", ".terminfo", "x"), shell_integration.Data()["terminfo/x/xterm-kitty"])
 	}
 	if err == nil {
 		err = tw.Close()
@@ -468,7 +471,7 @@ func bootstrap_script(cd *connection_data) (err error) {
 	}
 	maps.Copy(replacements, sensitive_data)
 	cd.replacements = replacements
-	cd.bootstrap_script = utils.UnsafeBytesToString(Data()["shell-integration/ssh/bootstrap."+cd.script_type].data)
+	cd.bootstrap_script = utils.UnsafeBytesToString(shell_integration.Data()["shell-integration/ssh/bootstrap."+cd.script_type].Data)
 	cd.bootstrap_script = prepare_script(cd.bootstrap_script, sd)
 	return err
 }
@@ -488,7 +491,7 @@ func wrap_bootstrap_script(cd *connection_data) {
 		encoded_script = base64.StdEncoding.EncodeToString(utils.UnsafeStringToBytes(cd.bootstrap_script))
 		unwrap_script = `"import base64, sys; eval(compile(base64.standard_b64decode(sys.argv[-1]), 'bootstrap.py', 'exec'))"`
 	} else {
-		// We cant rely on base64 being available on the remote system, so instead
+		// We can't rely on base64 being available on the remote system, so instead
 		// we quote the bootstrap script by replacing ' and \ with \v and \f
 		// also replacing \n and ! with \r and \b for tcsh
 		// finally surrounding with '
@@ -582,7 +585,7 @@ func change_colors(color_scheme string) (ans string, err error) {
 }
 
 func run_ssh(ssh_args, server_args, found_extra_args []string) (rc int, err error) {
-	go Data()
+	go shell_integration.Data()
 	go RelevantKittyOpts()
 	defer func() {
 		if data_shm != nil {
@@ -612,6 +615,13 @@ func run_ssh(ssh_args, server_args, found_extra_args []string) (rc int, err erro
 			fmt.Fprintf(os.Stderr, "Ignoring bad config line: %s:%d with error: %s", filepath.Base(x.Src_file), x.Line_number, x.Err)
 		}
 	}
+	if host_opts.Delegate != "" {
+		delegate_cmd, err := shlex.Split(host_opts.Delegate)
+		if err != nil {
+			return 1, fmt.Errorf("Could not parse delegate command: %#v with error: %w", host_opts.Delegate, err)
+		}
+		return 1, unix.Exec(utils.FindExe(delegate_cmd[0]), utils.Concat(delegate_cmd, ssh_args, server_args), os.Environ())
+	}
 	if host_opts.Share_connections {
 		kpid, err := strconv.Atoi(os.Getenv("KITTY_PID"))
 		if err != nil {
@@ -669,6 +679,9 @@ func run_ssh(ssh_args, server_args, found_extra_args []string) (rc int, err erro
 	if err != nil {
 		return 1, err
 	}
+	sigs := make(chan os.Signal, 8)
+	signal.Notify(sigs, unix.SIGINT, unix.SIGTERM)
+
 	if !cd.request_data {
 		rq := fmt.Sprintf("id=%s:pwfile=%s:pw=%s", cd.replacements["REQUEST_ID"], cd.replacements["PASSWORD_FILENAME"], cd.replacements["DATA_PASSWORD"])
 		err := term.ApplyOperations(tty.TCSANOW, tty.SetNoEcho)
@@ -685,11 +698,22 @@ func run_ssh(ssh_args, server_args, found_extra_args []string) (rc int, err erro
 			return 1, err
 		}
 	}
+	go func() {
+		_ = <-sigs
+		// ignore any interrupt and terminate signals as they will usually be sent to the ssh child process as well
+		// and we are waiting on that.
+	}()
 	err = c.Wait()
 	drain_potential_tty_garbage(term)
+	signal.Reset(unix.SIGINT, unix.SIGTERM)
 	if err != nil {
 		var exit_err *exec.ExitError
 		if errors.As(err, &exit_err) {
+			if state := exit_err.ProcessState.String(); state == "signal: interrupt" {
+				unix.Kill(os.Getpid(), unix.SIGINT)
+				// Give the signal time to be delivered
+				time.Sleep(20 * time.Millisecond)
+			}
 			return exit_err.ExitCode(), nil
 		}
 		return 1, err
@@ -720,10 +744,7 @@ func main(cmd *cli.Command, o *Options, args []string) (rc int, err error) {
 		return 1, err
 	}
 	if passthrough {
-		if len(found_extra_args) > 0 {
-			return 1, fmt.Errorf("The SSH kitten cannot work with the options: %s", strings.Join(maps.Keys(PassthroughArgs()), " "))
-		}
-		return 1, unix.Exec(SSHExe(), append([]string{"ssh"}, args...), os.Environ())
+		return 1, unix.Exec(SSHExe(), utils.Concat([]string{"ssh"}, ssh_args, server_args), os.Environ())
 	}
 	if os.Getenv("KITTY_WINDOW_ID") == "" || os.Getenv("KITTY_PID") == "" {
 		return 1, fmt.Errorf("The SSH kitten is meant to run inside a kitty window")
