@@ -13,6 +13,7 @@ import (
 	"unicode"
 
 	"kitty/tools/cli"
+	"kitty/tools/tty"
 	"kitty/tools/tui"
 	"kitty/tools/tui/loop"
 	"kitty/tools/tui/readline"
@@ -250,6 +251,8 @@ func (self *handler) update_codepoints() {
 	}
 }
 
+var debugprintln = tty.DebugPrintln
+
 func (self *handler) update_current_char() {
 	self.update_codepoints()
 	self.current_char = InvalidChar
