@@ -4,9 +4,7 @@
 from functools import partial
 
 import kitty.fast_data_types as defines
-from kitty.key_encoding import (
-    EventType, KeyEvent, decode_key_event, encode_key_event
-)
+from kitty.key_encoding import EventType, KeyEvent, decode_key_event, encode_key_event
 
 from . import BaseTest
 
@@ -92,7 +90,7 @@ class TestKeys(BaseTest):
         mkp('END', csi_num=1, trailer='F')
         mods_test(defines.GLFW_FKEY_F1, '\x1bOP', csi_num=1, trailer='P')
         mods_test(defines.GLFW_FKEY_F2, '\x1bOQ', csi_num=1, trailer='Q')
-        mods_test(defines.GLFW_FKEY_F3, '\x1bOR', csi_num=1, trailer='R')
+        mods_test(defines.GLFW_FKEY_F3, '\x1bOR', csi_num=13, trailer='~')
         mods_test(defines.GLFW_FKEY_F4, '\x1bOS', csi_num=1, trailer='S')
         mods_test(defines.GLFW_FKEY_F5, csi_num=15, trailer='~')
         mods_test(defines.GLFW_FKEY_F6, csi_num=17, trailer='~')
