@@ -36,18 +36,6 @@ const (
 	PM
 )
 
-type timer struct {
-	interval time.Duration
-	deadline time.Time
-	repeats  bool
-	id       IdType
-	callback TimerCallback
-}
-
-func (self *timer) update_deadline(now time.Time) {
-	self.deadline = now.Add(self.interval)
-}
-
 type Loop struct {
 	controlling_term                       *tty.Term
 	terminal_options                       TerminalStateOptions
