@@ -4,11 +4,41 @@ package loop
 
 import (
 	"fmt"
+	"reflect"
+	"runtime"
 	"time"
 
 	"golang.org/x/exp/slices"
+
+	"kitty/tools/tty"
 )
 
+var debugprintln = tty.DebugPrintln
+
+type timer struct {
+	interval time.Duration
+	deadline time.Time
+	repeats  bool
+	id       IdType
+	callback TimerCallback
+}
+
+func (self *timer) update_deadline(now time.Time) {
+	self.deadline = now.Add(self.interval)
+}
+
+func (self timer) String() string {
+	funcname := "<nil>"
+	if self.callback != nil {
+		p := reflect.ValueOf(self.callback).Pointer()
+		f := runtime.FuncForPC(p)
+		if f != nil {
+			funcname = f.Name()
+		}
+	}
+	return fmt.Sprintf("Timer(id=%d, callback=%s, deadline=%s, repeats=%v)", self.id, funcname, self.deadline.Sub(time.Now()), self.repeats)
+}
+
 func (self *Loop) add_timer(interval time.Duration, repeats bool, callback TimerCallback) (IdType, error) {
 	if self.timers == nil {
 		return 0, fmt.Errorf("Cannot add timers before starting the run loop, add them in OnInitialize instead")
@@ -36,22 +66,25 @@ func (self *Loop) remove_timer(id IdType) bool {
 
 func (self *Loop) dispatch_timers(now time.Time) error {
 	self.timers_temp = self.timers_temp[:0]
-	for _, t := range self.timers {
+	self.timers, self.timers_temp = self.timers_temp, self.timers
+	dispatched := false
+	for _, t := range self.timers_temp {
 		if now.After(t.deadline) {
+			dispatched = true
 			err := t.callback(t.id)
 			if err != nil {
 				return err
 			}
 			if t.repeats {
 				t.update_deadline(now)
-				self.timers_temp = append(self.timers_temp, t)
+				self.timers = append(self.timers, t)
 			}
+		} else {
+			self.timers = append(self.timers, t)
 		}
 	}
-	self.timers = self.timers[:len(self.timers_temp)]
-	if len(self.timers) > 0 {
-		copy(self.timers, self.timers_temp)
-		self.sort_timers()
+	if dispatched {
+		self.sort_timers() // needed because a timer callback could have added a new timer
 	}
 	return nil
 }
